Learn R Programming

allMT (version 0.1.1)

assess_stop_doses: Analyze physicians' compliance to dosing guidelines: STOP DOSE

Description

Evaluate number of times blood counts did not support physicians' STOP DOSE decision

Usage

assess_stop_doses(
  input_files_path,
  anc_threshold = NA,
  plt_threshold = NA,
  hb_threshold = NA
)

Value

Returns a list with (1) the 'STOP DOSE' analysis for each patient as listed below, (2) analysis summary as dataframe (3) analysis summary as HTML table in viewer.

  1. Pat ID

  2. Number of decisions where the physician stopped dose (a)

  3. Number of times blood counts did not support dose suspension (b)

  4. Discordance (%) = (\((b/a)*100)\)

Arguments

input_files_path

path to a file or a folder with MT csv files (in quotes).

anc_threshold

Absolute neutrophil count (ANC) value threshold below which doses should be stopped. NOTE: Ensure that the threshold value is represented with same unit as of the input ANC data.

plt_threshold

Platelet (PLT) value threshold below which doses should be stopped. NOTE: Ensure that the threshold value is represented with same unit as of the input PLT data.

hb_threshold

Hemoglobin (HB) value threshold below which doses should be stopped. NOTE: Ensure that the threshold value is represented with same unit as of the input Hb data.

See Also

assess_reduced_doses(), assess_increased_doses()

Examples

Run this code
pat_data <- system.file("extdata/processed_data/", "UPN_915.csv", package = "allMT")
assess_stop_doses(input_files_path = pat_data,
                  anc_threshold = 0.5, plt_threshold = 50, hb_threshold = 7)

# \donttest{
assess_stop_doses(input_files_path = pat_data,
                  anc_threshold = 0.5)

cohort_path = paste0(system.file("extdata/processed_data/", package = "allMT"), "/")
assess_stop_doses(input_files_path = cohort_path,
                  anc_threshold = 0.5,plt_threshold = 50, hb_threshold = 7)
# }

Run the code above in your browser using DataLab