Learn R Programming

allMT (version 0.1.1)

summarize_cohortMT: Plot summarized maintenance therapy (MT) data for a cohort

Description

Create an integrated summary graph illustrating weighted mean absolute neutrophil count (ANC) and dose information for each patient in the cohort.

Usage

summarize_cohortMT(input_files_path, anc_range, unit, dose_intensity_threshold)

Value

Summary graph

Arguments

input_files_path

Path to folder with MT csv files (in quotes)

anc_range

ANC target range as per the protocol: (c(lower threshold, upper threshold)). NOTE: Ensure that units are the same as unit of ANC in the input data.

unit

Choose either "million" or "billion".

  • "million" = million cells/L (x\(10^{6}\) cells/L or cells/\(\mu\)l)

  • "billion" = billion cells/L (x\(10^{9}\) cells/L or x\(10^{3}\) cells/\(\mu\)l)

dose_intensity_threshold

numeric value of reference drug dose intensity (%). (optional)

See Also

compare_cohorts()

Examples

Run this code
cohort_path = paste0(system.file("extdata/processed_data/", package = "allMT"), "/")
summarize_cohortMT (input_files_path = cohort_path, unit = "billion",
                    anc_range = c(0.75, 1.5), dose_intensity_threshold = c(80, 100))

# \donttest{
summarize_cohortMT(input_files_path = cohort_path,
                 unit = "billion", anc_range = c(0.8, 2), dose_intensity_threshold = 150)

# As per BFM protocol (Reference PMID - 15902295):
summarize_cohortMT (input_files_path = cohort_path,
                 unit = "billion", anc_range = c(2, NA), dose_intensity_threshold = 150)

# As per St Jude protocol (Reference PMID - 15902295):
summarize_cohortMT (input_files_path = cohort_path,
                 unit = "billion", anc_range = c(0.8, 2), dose_intensity_threshold = 100)

# }

Run the code above in your browser using DataLab