Learn R Programming

allMT (version 0.1.1)

assess_anemia: Assess hematological toxicities: Anemia

Description

Evaluate number of anemia episodes and their duration for a given patient or cohort

Usage

assess_anemia(input_files_path, hb_range, duration_hb = NA)

Value

Returns a list with (1) the anemia information for each patient as listed below, (2) analysis summary as dataframe (3) analysis summary as HTML table.

  1. Pat ID

  2. Number of particular toxicity episodes

  3. Duration of particular toxicity (in weeks)

  4. Number of long duration toxicity episodes

  5. Duration of long duration toxicity (in weeks)

Arguments

input_files_path

path to a file or a folder with MT csv files (in quotes).

hb_range

Hemoglobin (HB) value range of c(Anemic HB threshold, recovered HB threshold). NOTE: Ensure that units are the same as unit of HB in the input data.

duration_hb

numeric duration (in weeks) that is used to categorize event as "long duration anemia" (optional)

See Also

assess_neutropenia(), assess_thrombocytopenia()

Examples

Run this code
pat_data = system.file("extdata/processed_data/", "UPN_915.csv", package = "allMT")
assess_anemia(input_files_path = pat_data,
                      hb_range = c(7, 8), duration_hb = 3)

# \donttest{

cohort_path = paste0(system.file("extdata/processed_data/", package = "allMT"), "/")
assess_anemia(input_files_path = cohort_path,
                      hb_range = c(7, 8), duration_hb = 3)

result <- assess_anemia(input_files_path = pat_data,
                      hb_range = c(7, 8), duration_hb = 3)
print(result[[1]])
print(result[[2]])
print(result[[3]])
# }


Run the code above in your browser using DataLab