Learn R Programming

allMT (version 0.1.1)

assess_increased_doses: Analyze physicians' compliance to dosing guidelines: INCREASE DOSE

Description

Evaluate number of times blood counts did not support physicians' INCREASE DOSE decision

Usage

assess_increased_doses(
  input_files_path,
  anc_threshold = NA,
  plt_threshold = NA,
  hb_threshold = NA,
  escalation_factor,
  tolerated_dose_duration
)

Value

Returns a list with (1) the 'INCREASE DOSE' analysis for each patient as listed below, (2) analysis summary as dataframe (3) analysis summary as HTML table in viewer.

  1. Pat ID

  2. Number of decisions where the physician increased dose (a)

  3. Number of times blood counts did not support dose suspension (b)

  4. Discordance (%) = (\(1 - (b/a)*100)\)

Arguments

input_files_path

path to a file or a folder with MT csv files (in quotes).

anc_threshold

Absolute neutrophil count (ANC) value threshold above which doses should be increased. NOTE: Ensure that the threshold value is represented with same unit as of the input ANC data.

plt_threshold

Platelet (PLT) value threshold above which doses should be increased. NOTE: Ensure that the threshold value is represented with same unit as of the input PLT data.

hb_threshold

Hemoglobin (HB) value threshold below which doses should be increased. NOTE: Ensure that the threshold value is represented with same unit as of the input Hb data.

escalation_factor

Percentage of increase from previous tolerated dose to be considered as "increased" dose.

tolerated_dose_duration

Number of weeks with ANC, PLT, and Hb values consistently above threshold with same dose prescription, following which dose should be increased.

See Also

time_to_first_dose_increase(), assess_reduced_doses(), assess_stop_doses()

Examples

Run this code

cohort_path = paste0(system.file("extdata/processed_data/", package = "allMT"), "/")
assess_increased_doses(input_files_path = cohort_path, anc_threshold = 0.75,
                      plt_threshold = 75, hb_threshold = 8,
                      escalation_factor = 25, tolerated_dose_duration = 8)
# \donttest{

pat_data = system.file("extdata/processed_data/", "UPN_914.csv", package = "allMT")
assess_increased_doses (input_files_path = pat_data, anc_threshold = 0.75,
                      plt_threshold = 75, hb_threshold = 8,
                      escalation_factor = 15, tolerated_dose_duration = 6)

assess_increased_doses(input_files_path = cohort_path,
                      anc_threshold = 0.7, plt_threshold = 60)
# }


Run the code above in your browser using DataLab