Learn R Programming

allMT (version 0.1.1)

assess_neutropenia: Assess hematological toxicities: Neutropenia

Description

Evaluate number of neutropenia episodes and their duration for a given patient or cohort

Usage

assess_neutropenia(input_files_path, anc_range, duration_anc = NA)

Value

Returns a list with (1) the neutropenia information for each patient as listed below, (2) analysis summary as dataframe (3) analysis summary as HTML table.

  1. Pat ID

  2. Number of particular toxicity episodes

  3. Duration of particular toxicity (in weeks)

  4. Number of long duration toxicity episodes

  5. Duration of long duration toxicity (in weeks)

Arguments

input_files_path

path to a file or a folder with MT csv files (in quotes).

anc_range

Absolute neutrophil count (ANC) value range of c(Neutropenic ANC threshold, recovered ANC threshold). NOTE: Ensure that units are the same as unit of ANC in the input data.

duration_anc

numeric duration (in weeks) that is used to categorize event as "long duration neutropenia" (optional)

See Also

assess_anemia(), assess_thrombocytopenia()

Examples

Run this code
pat_data = system.file("extdata/processed_data/", "UPN_915.csv", package = "allMT")
assess_neutropenia(input_files_path = pat_data,
                      anc_range = c(0.5, 0.75), duration_anc = 3)

# \donttest{

cohort_path = paste0(system.file("extdata/processed_data/", package = "allMT"), "/")
assess_neutropenia(input_files_path = cohort_path,
                      anc_range = c(0.5, 0.75), duration_anc = 3)


result <- assess_neutropenia(input_files_path = pat_data,
                      anc_range = c(0.5, 0.75), duration_anc = 3)
print(result[[1]])
print(result[[2]])
print(result[[3]])
# }

Run the code above in your browser using DataLab