Learn R Programming

allMT (version 0.1.1)

assess_thrombocytopenia: Assess hematological toxicities : Thrombocytopenia

Description

Evaluate number of thrombocytopenia episodes and their duration for a given patient or cohort

Usage

assess_thrombocytopenia(input_files_path, plt_range, duration_plt = NA)

Value

Returns a list with (1) the thrombocytopenia information for each patient as listed below, (2) analysis summary as dataframe (3) analysis summary as HTML table.

  1. Pat ID

  2. Number of particular toxicity episodes

  3. Duration of particular toxicity (in weeks)

  4. Number of long duration toxicity episodes

  5. Duration of long duration toxicity (in weeks)

Arguments

input_files_path

path to a file or a folder with MT csv files (in quotes).

plt_range

Platelet (PLT) value range of c(thrombocytopenic PLT threshold, recovered PLT threshold). NOTE: Ensure that units are the same as unit of PLT in the input data.

duration_plt

numeric duration (in weeks) that is used to categorize event as "long duration thrombocytopenia" (optional)

See Also

assess_neutropenia(), assess_anemia()

Examples

Run this code
pat_data = system.file("extdata/processed_data/", "UPN_914.csv", package = "allMT")
assess_thrombocytopenia(input_files_path = pat_data,
                      plt_range = c(50, 75), duration_plt = 3)

# \donttest{
cohort_path = paste0(system.file("extdata/processed_data/", package = "allMT"), "/")
assess_thrombocytopenia(input_files_path = cohort_path,
                      plt_range = c(50, 75), duration_plt = 3)


result <- assess_thrombocytopenia(input_files_path = pat_data,
                      plt_range = c(0.5, 0.75), duration_plt = 3)
print(result[[1]])
print(result[[2]])
print(result[[3]])
# }

Run the code above in your browser using DataLab